joop documentation — joop 0.0.1 documentation

# joop documentation

## Welcome to joop

OOP Paradigms with an emphasis on DAO patterns, HTMX, and AlpineJS.

- Free software: Apache Software License 2.0

## Features

- HTML Components for server-side rendering.

Contents:

- API Documentation
  - `hello_world()`
  - joop.web
  - joop.dao
  - joop.cli
  - joop.flask
  - joop.http
- Changelog
  - Version 0.0.4 (2026-02-05)
  - Version 0.0.3 (2026-02-05)
  - Version 0.0.2 (2026-02-03)
  - Version 0.0.1 (2026-02-02)